@@ -73,6 +73,8 @@ class DatabaseOperations(BaseDatabaseOperations):
 
 
 class DatabaseWrapper(BaseDatabaseWrapper):
+    vendor = 'ldap'
+
     def __init__(self, *args, **kwargs):
         super(DatabaseWrapper, self).__init__(*args, **kwargs)
 
@@ -143,5 +145,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                                              attrlist)
         output = []
         for dn, attrs in results:
-            output.append((dn.decode(self.charset), attrs))
+            # skip referrals
+            if dn is not None:
+                output.append((dn.decode(self.charset), attrs))
         return output
